@@ -17,18 +17,19 @@ import os
 import logging
 _log = logging.getLogger('macsyfinder.' + __name__)
 
-
 import abc
 from threading import Lock
 from itertools import groupby
-from database import Indexes, RepliconDB
+from .database import Indexes, RepliconDB
 
 
 class HMMReport(object):
     """
-    Handle the results from the HMM search. Extract a synthetic report from the raw hmmer output, after having applied a hit filtering.
+    Handle the results from the HMM search. Extract a synthetic report from the raw hmmer output,
+    after having applied a hit filtering.
     This class is an **abstract class**. There are two implementations of this abstract class
-    depending on wether the input sequence dataset is "ordered" ("gembase" or "ordered_replicon" db_type) or not ("unordered" or "unordered_replicon" db_type).
+    depending on whether the input sequence dataset is "ordered" ("gembase" or "ordered_replicon" db_type)
+    or not ("unordered" or "unordered_replicon" db_type).
     """
 
     __metaclass__ = abc.ABCMeta
@@ -63,13 +64,16 @@ class HMMReport(object):
         """
         Print information on filtered hits
         """
-        s = "# gene: %s extract from %s hmm output\n" % (self.gene.name, self._hmmer_raw_out)
-        s += "# profile length= %d\n" % len(self.gene.profile)
-        s += "# i_evalue threshold= %f\n" % self.cfg.i_evalue_sel
-        s += "# coverage threshold= %f\n" % self.cfg.coverage_profile
-        #s += "# hit_id replicon_name position_hit gene_name gene_system i_eval score coverage\n"
-        #s += "# hit_id replicon_name position_hit gene_name gene_system i_eval score profile_coverage sequence_coverage begin end\n"
-        s += "# hit_id replicon_name position_hit hit_sequence_length gene_name gene_system i_eval score profile_coverage sequence_coverage begin end\n"
+        s = """# gene: {gene_name} extract from {hmmer_out} hmm output
+# profile length= {profile_len:d}
+# i_evalue threshold= {i_evalue:.3f}
+# coverage threshold= {coverage:.3f}
+# hit_id replicon_name position_hit hit_sequence_length gene_name gene_system i_eval score profile_coverage sequence_coverage begin end
+""".format(gene_name=self.gene.name, hmmer_out=self._hmmer_raw_out,
+                                     profile_len=len(self.gene.profile),
+                                     i_evalue=self.cfg.i_evalue_sel,
+                                     coverage=self.cfg.coverage_profile)
+        
         for h in self.hits:
             s += str(h)
         return s
@@ -77,8 +81,9 @@ class HMMReport(object):
 
     def save_extract(self):
         """
-        Write the string representation of the extact report in a file.
-        The name of this file is the concatenation of the gene name and of the "res_extract_suffix" from the config object
+        Write the string representation of the extract report in a file.
+        The name of this file is the concatenation of the gene name and of the "res_extract_suffix"
+        from the config object
         """
         with self._lock:
             extract_out_name = self.gene.name + self.cfg.res_extract_suffix
@@ -101,7 +106,7 @@ class HMMReport(object):
         """
         :param line: the line to parse
         :type line: string
-        :return: True if it's the begining of a new hit in Hmmer raw output files.\
+        :return: True if it's the beginning of a new hit in Hmmer raw output files.
          False otherwise
         :rtype: boolean.
         """
@@ -154,7 +159,8 @@ class HMMReport(object):
 
     def _parse_hmm_body(self, hit_id, gene_profile_lg, seq_lg, coverage_treshold, replicon_name, position_hit, i_evalue_sel, b_grp):
         """
-        Parse the raw Hmmer output to extract the hits, and filter them with threshold criteria selected ("coverage_profile" and "i_evalue_select" command-line parameters) 
+        Parse the raw Hmmer output to extract the hits, and filter them with threshold criteria selected
+        ("coverage_profile" and "i_evalue_select" command-line parameters)
 
         :param hit_id: the sequence identifier
         :type hit_id: string 
@@ -189,12 +195,12 @@ class HMMReport(object):
                 else:
                     fields = line.split()
                     try:
-                        if(len(fields) > 1 and float(fields[5]) <= i_evalue_sel):
+                        if len(fields) > 1 and float(fields[5]) <= i_evalue_sel:
                             cov_profile = (float(fields[7]) - float(fields[6]) + 1) / gene_profile_lg
                             begin = int(fields[9])
                             end = int(fields[10])
                             cov_gene = (float(end) - float(begin) + 1) / seq_lg # To be added in Gene: sequence_length
-                            if (cov_profile >= coverage_treshold):
+                            if cov_profile >= coverage_treshold:
                                 i_eval = float(fields[5])
                                 score = float(fields[2])
                                 hits.append(Hit(self.gene,
@@ -209,7 +215,7 @@ class HMMReport(object):
                                                 cov_gene,
                                                 begin,
                                                 end))
-                    except ValueError, err:
+                    except ValueError as err:
                         msg = "Invalid line to parse :{0}:{1}".format(line, err)
                         _log.debug(msg)
                         raise ValueError(msg)
@@ -221,7 +227,7 @@ class GeneralHMMReport(HMMReport):
     Handle HMM report. Extract a synthetic report from the raw hmmer output.
     Dedicated to any type of 'unordered' datasets.
     """
-    #pass
+
     def extract(self):
         """
         Parse the output file of hmmer compute from an unordered genes base
@@ -242,20 +248,21 @@ class GeneralHMMReport(HMMReport):
 
             with open(self._hmmer_raw_out, 'r') as hmm_out:
                 i_evalue_sel = self.cfg.i_evalue_sel
-                coverage_treshold = self.cfg.coverage_profile
+                coverage_threshold = self.cfg.coverage_profile
                 gene_profile_lg = len(self.gene.profile)
                 hmm_hits = (x[1] for x in groupby(hmm_out, self._hit_start))
-                #drop summary
+                # drop summary
                 hmm_hits.next()
                 for hmm_hit in hmm_hits:
                     hit_id = self._parse_hmm_header(hmm_hit)
                     seq_lg, position_hit = my_db[hit_id]
 
-                    #replicon_name = self.cfg. # Define a variable in further devt
+                    # replicon_name = self.cfg. # Define a variable in further devt
                     replicon_name = "Unordered"
 
                     body = hmm_hits.next()
-                    h = self._parse_hmm_body(hit_id, gene_profile_lg, seq_lg, coverage_treshold, replicon_name, position_hit, i_evalue_sel, body)
+                    h = self._parse_hmm_body(hit_id, gene_profile_lg, seq_lg, coverage_threshold,
+                                             replicon_name, position_hit, i_evalue_sel, body)
                     self.hits += h
                 self.hits.sort()
                 return self.hits
@@ -266,7 +273,7 @@ class OrderedHMMReport(HMMReport):
     Handle HMM report. Extract a synthetic report from the raw hmmer output.
     Dedicated to 'ordered_replicon' datasets.
     """
-    #pass
+
     def extract(self):
         """
         Parse the output file of Hmmer obtained from a search in an ordered set of sequences
@@ -287,10 +294,10 @@ class OrderedHMMReport(HMMReport):
 
             with open(self._hmmer_raw_out, 'r') as hmm_out:
                 i_evalue_sel = self.cfg.i_evalue_sel
-                coverage_treshold = self.cfg.coverage_profile
+                coverage_threshold = self.cfg.coverage_profile
                 gene_profile_lg = len(self.gene.profile)
                 hmm_hits = (x[1] for x in groupby(hmm_out, self._hit_start))
-                #drop summary
+                # drop summary
                 hmm_hits.next()
                 for hmm_hit in hmm_hits:
                     hit_id = self._parse_hmm_header(hmm_hit)
@@ -298,7 +305,8 @@ class OrderedHMMReport(HMMReport):
                     replicon_name = RepliconDB.ordered_replicon_name
 
                     body = hmm_hits.next()
-                    h = self._parse_hmm_body(hit_id, gene_profile_lg, seq_lg, coverage_treshold, replicon_name, position_hit, i_evalue_sel, body)
+                    h = self._parse_hmm_body(hit_id, gene_profile_lg, seq_lg, coverage_threshold,
+                                             replicon_name, position_hit, i_evalue_sel, body)
                     self.hits += h
                 self.hits.sort()
                 return self.hits
@@ -329,18 +337,18 @@ class GembaseHMMReport(HMMReport):
 
             with open(self._hmmer_raw_out, 'r') as hmm_out:
                 i_evalue_sel = self.cfg.i_evalue_sel
-                coverage_treshold = self.cfg.coverage_profile
+                coverage_threshold = self.cfg.coverage_profile
                 gene_profile_lg = len(self.gene.profile)
                 hmm_hits = (x[1] for x in groupby(hmm_out, self._hit_start))
-                #drop summary
+                # drop summary
                 hmm_hits.next()
                 for hmm_hit in hmm_hits:
                     hit_id = self._parse_hmm_header(hmm_hit)
                     seq_lg, position_hit = my_db[hit_id]
-                    fields_hit = hit_id.split('_')
-                    replicon_name = fields_hit[0]
+                    replicon_name = "_".join(hit_id.split('_')[:-1])
                     body = hmm_hits.next()
-                    h = self._parse_hmm_body(hit_id, gene_profile_lg, seq_lg, coverage_treshold, replicon_name, position_hit, i_evalue_sel, body)
+                    h = self._parse_hmm_body(hit_id, gene_profile_lg, seq_lg, coverage_threshold,
+                                             replicon_name, position_hit, i_evalue_sel, body)
                     self.hits += h
                 self.hits.sort()
                 return self.hits
@@ -396,22 +404,24 @@ class Hit(object):
         """
         Print useful information on the Hit: regarding Hmmer statistics, and sequence information
         """
-        return "%s\t%s\t%d\t%d\t%s\t%s\t%s\t%s\t%f\t%f\t%d\t%d\n" % (self.id,
-                                                     self.replicon_name,
-                                                     self.position,
-                                                     self.seq_length,
-                                                     self.gene.name,
-                                                     self.system.name,
-                                                     self.i_eval,
-                                                     self.score,
-                                                     self.profile_coverage, 
-                                                     self.sequence_coverage,
-                                                     self.begin_match,
-                                                     self.end_match)
+        return "{id}\t{replicon_name}\t{position:d}\t{seq_len:d}\t{gene_name}\t{system_name}\t{i_evalue:.3e}\t{score:.3f}\
+\t{profil_cov:.3f}\t{seq_cov:.3f}\t{begin_match:d}\t{end_match:d}\n".format(id=self.id,
+                                                                             replicon_name=self.replicon_name,
+                                                                             position=self.position,
+                                                                             seq_len=self.seq_length,
+                                                                             gene_name=self.gene.name,
+                                                                             system_name=self.system.name,
+                                                                             i_evalue=self.i_eval,
+                                                                             score=self.score,
+                                                                             profil_cov=self.profile_coverage,
+                                                                             seq_cov=self.sequence_coverage,
+                                                                             begin_match=self.begin_match,
+                                                                             end_match=self.end_match)
 
     def __cmp__(self, other):
         """
-        Compare two Hits. If the sequence identifier is the same, do the comparison on the score. Otherwise, do it on alphabetical comparison of the sequence identifier.
+        Compare two Hits. If the sequence identifier is the same, do the comparison on the score.
+        Otherwise, do it on alphabetical comparison of the sequence identifier.
 
         :param other: the hit to compare to the current object
         :type other: :class:`macsypy.report.Hit` object
@@ -419,7 +429,12 @@ class Hit(object):
         """
         if self.id == other.id:
             if not self.gene.is_homolog(other.gene): 
-                _log.warning("Non homologs match: %s (%s) %s (%s) for %s"%(self.gene.name, self.system.name, other.gene.name, other.system.name, self.id))
+                _log.warning("Non homologs match: {g_name} ({sys_name}) {other_g_name} ({other_sys_name}) for {id}".format(\
+                    g_name=self.gene.name,
+                    sys_name=self.system.name,
+                    other_g_name=other.gene.name,
+                    other_sys_name=other.system.name,
+                    id=self.id))
             return cmp(self.score, other.score)
         else:
             return cmp(self.id, other.id)
@@ -433,8 +448,7 @@ class Hit(object):
         :return: the result of the comparison
         :rtype: boolean
         """
-        return (
-                self.gene.name == other.gene.name and
+        return (self.gene.name == other.gene.name and
                 self.system.name == other.system.name and
                 self.id == other.id and
                 self.seq_length == other.seq_length and
